@@ -77,11 +77,11 @@ func NewCmdView(f *cmdutil.Factory, runF func(*ViewOptions) error) *cobra.Comman
 }
 
 var defaultFields = []string{
-	"url", "number", "title", "state", "body", "author",
+	"url", "number", "title", "state", "body", "author", "autoMergeRequest",
 	"isDraft", "maintainerCanModify", "mergeable", "additions", "deletions", "commitsCount",
 	"baseRefName", "headRefName", "headRepositoryOwner", "headRepository", "isCrossRepository",
 	"reviewRequests", "reviews", "assignees", "labels", "projectCards", "milestone",
-	"comments", "reactionGroups", "createdAt",
+	"comments", "reactionGroups", "createdAt", "statusCheckRollup",
 }
 
 func viewRun(opts *ViewOptions) error {
@@ -157,6 +157,15 @@ func printRawPrPreview(io *iostreams.IOStreams, pr *api.PullRequest) error {
 	fmt.Fprintf(out, "url:\t%s\n", pr.URL)
 	fmt.Fprintf(out, "additions:\t%s\n", cs.Green(strconv.Itoa(pr.Additions)))
 	fmt.Fprintf(out, "deletions:\t%s\n", cs.Red(strconv.Itoa(pr.Deletions)))
+	var autoMerge string
+	if pr.AutoMergeRequest == nil {
+		autoMerge = "disabled"
+	} else {
+		autoMerge = fmt.Sprintf("enabled\t%s\t%s",
+			pr.AutoMergeRequest.EnabledBy.Login,
+			strings.ToLower(pr.AutoMergeRequest.MergeMethod))
+	}
+	fmt.Fprintf(out, "auto-merge:\t%s\n", autoMerge)
 
 	fmt.Fprintln(out, "--")
 	fmt.Fprintln(out, pr.Body)
@@ -171,17 +180,30 @@ func printHumanPrPreview(opts *ViewOptions, pr *api.PullRequest) error {
 	// Header (Title and State)
 	fmt.Fprintf(out, "%s #%d\n", cs.Bold(pr.Title), pr.Number)
 	fmt.Fprintf(out,
-		"%s • %s wants to merge %s into %s from %s • %s • %s %s \n",
+		"%s • %s wants to merge %s into %s from %s • %s\n",
 		shared.StateTitleWithColor(cs, *pr),
 		pr.Author.Login,
 		text.Pluralize(pr.Commits.TotalCount, "commit"),
 		pr.BaseRefName,
 		pr.HeadRefName,
 		text.FuzzyAgo(opts.Now(), pr.CreatedAt),
+	)
+
+	// added/removed
+	fmt.Fprintf(out,
+		"%s %s",
 		cs.Green("+"+strconv.Itoa(pr.Additions)),
 		cs.Red("-"+strconv.Itoa(pr.Deletions)),
 	)
 
+	// checks
+	checks := pr.ChecksStatus()
+	if summary := shared.PrCheckStatusSummaryWithColor(cs, checks); summary != "" {
+		fmt.Fprintf(out, " • %s\n", summary)
+	} else {
+		fmt.Fprintln(out)
+	}
+
 	// Reactions
 	if reactions := shared.ReactionGroupList(pr.ReactionGroups); reactions != "" {
 		fmt.Fprint(out, reactions)
@@ -210,6 +232,29 @@ func printHumanPrPreview(opts *ViewOptions, pr *api.PullRequest) error {
 		fmt.Fprintln(out, pr.Milestone.Title)
 	}
 
+	// Auto-Merge status
+	autoMerge := pr.AutoMergeRequest
+	if autoMerge != nil {
+		var mergeMethod string
+		switch autoMerge.MergeMethod {
+		case "MERGE":
+			mergeMethod = "a merge commit"
+		case "REBASE":
+			mergeMethod = "rebase and merge"
+		case "SQUASH":
+			mergeMethod = "squash and merge"
+		default:
+			mergeMethod = fmt.Sprintf("an unknown merge method (%s)", autoMerge.MergeMethod)
+		}
+		fmt.Fprintf(out,
+			"%s %s by %s, using %s\n",
+			cs.Bold("Auto-merge:"),
+			cs.Green("enabled"),
+			autoMerge.EnabledBy.Login,
+			mergeMethod,
+		)
+	}
+
 	// Body
 	var md string
 	var err error
